@@ -1,20 +1,43 @@
 # Plot of fitted curves using columns of on extended dataframe to optionnally code 
 # for color and or facet 
 curvesplot <- function(extendedres, xmin = 0, xmax, y0shift = TRUE, 
-                       facetby, colorby, removelegend = FALSE,  
-                        npoints = 50, line.size = 0.2, line.alpha = 1)
+                       facetby, free.y.scales = FALSE, colorby, removelegend = FALSE,  
+                        npoints = 500, line.size = 0.2, line.alpha = 1,
+                       dose_log_transfo = FALSE)
 {
   if (missing(extendedres) | !is.data.frame(extendedres))
     stop("The first argument of curvesplot must be a dataframe 
          (see ?curvesplot for details).")
-  # ajouter un test sur le nom des colonnes indispensables !!!!!!!!!!!!!!!!!!!!!!!
-  if (missing(xmax)) 
+
+  cnames <- colnames(extendedres)
+  if (any(!is.element(c("id", "model", "b", "c", "d", "e", "f"), cnames)))
+    stop("The first argument of curvesplot must be a dataframe
+    containing at least columns named id, model, b, c, d, e and f.")
+  
+    if (missing(xmax)) 
     stop("xmax must be given. You can fix it at max(f$omicdata$dose)} 
          with f the output of drcfit()")
-  x2plot <- seq(xmin, xmax, length.out = npoints)
+  if (dose_log_transfo)
+  {
+    if (xmin == 0)
+      stop("When using a log scale for the dose, a strictly positive value must be given for xmin.")
+    x2plot <- 10^seq(log10(xmin), log10(xmax), length.out = npoints)
+  } else
+  {
+    x2plot <- seq(xmin, xmax, length.out = npoints)
+  }
+  
   ns <- nrow(extendedres)
   N <- ns * npoints
   
+  if (free.y.scales)
+  {
+    scales.arg <- "free_y"
+  } else
+  {
+    scales.arg <- "fixed"
+  }
+  
   curves2plot <- data.frame(x = rep(x2plot, ns), 
                             id = rep(extendedres$id, each = npoints),
                             y = numeric(length = N))
@@ -66,7 +89,7 @@ curvesplot <- function(extendedres, xmin = 0, xmax, y0shift = TRUE,
       curves2plot$facetby <- rep(extendedres[, facetby], each = npoints)
       gg <- ggplot(data = curves2plot, mapping = aes_(x = quote(x), y = quote(y), group = quote(id))) +
         geom_line(size = line.size, alpha = line.alpha) + 
-        facet_wrap(~ facetby) 
+        facet_wrap(~ facetby, scales = scales.arg) 
     } else
       # color only
       if (missing(facetby))
@@ -86,8 +109,12 @@ curvesplot <- function(extendedres, xmin = 0, xmax, y0shift = TRUE,
         curves2plot$facetby <- rep(extendedres[, facetby], each = npoints)
         curves2plot$colorby <- rep(extendedres[, colorby], each = npoints)
         gg <- ggplot(data = curves2plot, mapping = aes_(x = quote(x), y = quote(y), group = quote(id), colour = quote(colorby))) +
-          geom_line(size = line.size, alpha = line.alpha) + facet_wrap(~ facetby)  
+          geom_line(size = line.size, alpha = line.alpha) + facet_wrap(~ facetby, scales = scales.arg)  
       }
   if (removelegend) gg <- gg + theme(legend.position = "none") 
+  
+  if (dose_log_transfo)
+    gg <- gg + scale_x_log10()
+  
   return(gg)
 }
\ No newline at end of file
