@@ -1,8 +1,20 @@
 ecdfplotwithCI <- function(variable, CI.lower, CI.upper, by, CI.col = "blue", CI.alpha = 1, 
                            add.point = TRUE, point.size = 1, point.type = 16)
 {
+  if (!is.numeric(variable))
+    stop("Arguments variable, CI.lower and CI.upper must be numeric vectors of the same size")
+  leng <- length(variable)
+  if (!is.numeric(CI.lower) | (length(CI.lower) != leng) |
+      !is.numeric(CI.upper) | (length(CI.upper) != leng))
+    stop("Arguments variable, CI.lower and CI.upper must be numeric vectors of the same size")
   d <- data.frame(variable = variable, lower = CI.lower, upper = CI.upper)
-  if (!missing(by)) d$by <- by 
+  
+  if (!missing(by)) 
+  {
+    if (length(by) != leng)
+      stop("Argument by must be a factor of the same length as argument variable")
+    d$by <- as.factor(by)
+  } 
   if (is.factor(CI.col)) d$CI.col <- CI.col
   if (is.factor(point.type)) d$point.type <- point.type
   
